#!/usr/bin/env python3
"""Article MCP 模块执行入口
支持 python -m article_mcp 命令
"""

from .cli import main

if __name__ == "__main__":
    main()
